==> open-xchange-oauth_6.22.0.orig.tar.bz2: open-xchange-oauth-6.22.0/com.openexchange.oauth/src/com/openexchange/oauth/osgi/InvalidationListenerServiceTracker.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.oauth.osgi;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.oauth.OAuthAccountInvalidationListener;
import com.openexchange.oauth.internal.InvalidationListenerRegistry;


/**
 * {@link InvalidationListenerServiceTracker}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class InvalidationListenerServiceTracker implements ServiceTrackerCustomizer<OAuthAccountInvalidationListener, OAuthAccountInvalidationListener> {
    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(InvalidationListenerServiceTracker.class));

    private final BundleContext context;

    /**
     * Initializes a new {@link InvalidationListenerServiceTracker}.
     */
    public InvalidationListenerServiceTracker(final BundleContext context) {
        super();
        this.context = context;
    }

    @Override
    public OAuthAccountInvalidationListener addingService(final ServiceReference<OAuthAccountInvalidationListener> reference) {
        final OAuthAccountInvalidationListener addedService = context.getService(reference);
        if (InvalidationListenerRegistry.getInstance().addInvalidationListener( addedService)) {
            return addedService;
        }
        LOG.warn(new StringBuilder(64).append("Duplicate invalidation listener \"").append(addedService.getClass().getName()).append(
            "\" is not be added to registry."));
        // This service needs not to be tracked, thus return null
        context.ungetService(reference);
        return null;
    }

    @Override
    public void modifiedService(final ServiceReference<OAuthAccountInvalidationListener> reference, final OAuthAccountInvalidationListener service) {
        // Nothing to do
    }

    @Override
    public void removedService(final ServiceReference<OAuthAccountInvalidationListener> reference, final OAuthAccountInvalidationListener service) {
        if (null != service) {
            try {
                InvalidationListenerRegistry.getInstance().removeInvalidationListener(service);
            } finally {
                context.ungetService(reference);
            }
        }
    }


}

==> open-xchange-oauth_7.4.2.orig.tar.bz2: open-xchange-oauth-7.4.2/com.openexchange.oauth/src/com/openexchange/oauth/osgi/InvalidationListenerServiceTracker.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.oauth.osgi;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.oauth.OAuthAccountInvalidationListener;
import com.openexchange.oauth.internal.InvalidationListenerRegistry;


/**
 * {@link InvalidationListenerServiceTracker}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class InvalidationListenerServiceTracker implements ServiceTrackerCustomizer<OAuthAccountInvalidationListener, OAuthAccountInvalidationListener> {
    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(InvalidationListenerServiceTracker.class);

    private final BundleContext context;

    /**
     * Initializes a new {@link InvalidationListenerServiceTracker}.
     */
    public InvalidationListenerServiceTracker(final BundleContext context) {
        super();
        this.context = context;
    }

    @Override
    public OAuthAccountInvalidationListener addingService(final ServiceReference<OAuthAccountInvalidationListener> reference) {
        final OAuthAccountInvalidationListener addedService = context.getService(reference);
        if (InvalidationListenerRegistry.getInstance().addInvalidationListener( addedService)) {
            return addedService;
        }
        LOG.warn("Duplicate invalidation listener \"{}\" is not be added to registry.", addedService.getClass().getName());
        // This service needs not to be tracked, thus return null
        context.ungetService(reference);
        return null;
    }

    @Override
    public void modifiedService(final ServiceReference<OAuthAccountInvalidationListener> reference, final OAuthAccountInvalidationListener service) {
        // Nothing to do
    }

    @Override
    public void removedService(final ServiceReference<OAuthAccountInvalidationListener> reference, final OAuthAccountInvalidationListener service) {
        if (null != service) {
            try {
                InvalidationListenerRegistry.getInstance().removeInvalidationListener(service);
            } finally {
                context.ungetService(reference);
            }
        }
    }


}
